api

package
v0.0.0-...-34c3f81 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 1, 2021 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CreateRequest

type CreateRequest struct {
	Order order.Order
}

CreateRequest holds the request parameters for the Create method.

type CreateResponse

type CreateResponse struct {
	ID  string `json:"id"`
	Err error  `json:"error,omitempty"`
}

CreateResponse holds the response values for the Create method.

type Endpoints

type Endpoints struct {
	Create            endpoint.Endpoint
	GetByID           endpoint.Endpoint
	RemoveByID        endpoint.Endpoint
	GetMarketSnapshot endpoint.Endpoint
}

Endpoints holds all Go kit endpoints for the Order service.

func MakeEndpoints

func MakeEndpoints(s order.OrderService) Endpoints

MakeEndpoints initializes all Go kit endpoints for the Order service.

type GetByIDRequest

type GetByIDRequest struct {
	ID string
}

GetByIDRequest holds the request parameters for the GetByID method.

type GetByIDResponse

type GetByIDResponse struct {
	Order order.Order `json:"order"`
	Err   error       `json:"error,omitempty"`
}

GetByIDResponse holds the response values for the GetByID method.

type GetMarketSnapshotRequest

type GetMarketSnapshotRequest struct{}

GetMarketSnapshotRequest holds

type GetMarketSnapshotResponse

type GetMarketSnapshotResponse struct {
	MarketSnapshot order.MarketSnapshot `json:"result"`
	Err            error                `json:"error,omitempty"`
}

GetMarketSnapshotResponse holds the response values for the GetByID method.

type RemoveByIDRequest

type RemoveByIDRequest struct {
	ID string
}

RemoveByIDRequest holds the request parameters for the RemoveByID method.

type RemoveByIDResponse

type RemoveByIDResponse struct {
	Err error `json:"error,omitempty"`
}

RemoveByIDResponse holds the response values for the RemoveByID method.

Jump to