Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateRequest ¶
CreateRequest holds the request parameters for the Create method.
type CreateResponse ¶
CreateResponse holds the response values for the Create method.
type Endpoints ¶
type Endpoints struct {
Create endpoint.Endpoint
GetByID endpoint.Endpoint
RemoveByID endpoint.Endpoint
GetMarketSnapshot endpoint.Endpoint
}
Endpoints holds all Go kit endpoints for the Order service.
func MakeEndpoints ¶
func MakeEndpoints(s order.OrderService) Endpoints
MakeEndpoints initializes all Go kit endpoints for the Order service.
type GetByIDRequest ¶
type GetByIDRequest struct {
ID string
}
GetByIDRequest holds the request parameters for the GetByID method.
type GetByIDResponse ¶
GetByIDResponse holds the response values for the GetByID method.
type GetMarketSnapshotRequest ¶
type GetMarketSnapshotRequest struct{}
GetMarketSnapshotRequest holds
type GetMarketSnapshotResponse ¶
type GetMarketSnapshotResponse struct {
MarketSnapshot order.MarketSnapshot `json:"result"`
Err error `json:"error,omitempty"`
}
GetMarketSnapshotResponse holds the response values for the GetByID method.
type RemoveByIDRequest ¶
type RemoveByIDRequest struct {
ID string
}
RemoveByIDRequest holds the request parameters for the RemoveByID method.
type RemoveByIDResponse ¶
type RemoveByIDResponse struct {
Err error `json:"error,omitempty"`
}
RemoveByIDResponse holds the response values for the RemoveByID method.